Si usted es un colaborador activo de este proyecto, agregue una entrada en el lugar correspondiente según el siguiente formato:

- [1er nombre] [2do nombre] [1er apellido] [2do apellido] [<CORREO>], Twitter: [@Cuenta]


Las siguientes personas han trabajado en este proyecto (en orden alfabético):

- José Francisco Guerrero Rangel <jsfrncscg@gmail.com>, Twitter: @jsfrncscg
- Luis Alejandro Martínez Faneyth <luis@huntingbears.com.ve>, Twitter: @LuisAlejandro


